==> akonadi-search-22.07.80.tar.xz: akonadi-search-22.07.80/runner/plasma-krunner-pimcontacts.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "dvratil@kde.org",
                "Name": "Daniel Vrátil",
                "Name[az]": "sDaniel Vrátil",
                "Name[bg]": "Daniel Vrátil",
                "Name[ca@valencia]": "Daniel Vrátil",
                "Name[ca]": "Daniel Vrátil",
                "Name[cs]": "Daniel Vrátil",
                "Name[de]": "Daniel Vrátil",
                "Name[es]": "Daniel Vrátil",
                "Name[fi]": "Daniel Vrátil",
                "Name[fr]": "Daniel Vrátil",
                "Name[ia]": "Daniel Vrátil",
                "Name[it]": "Daniel Vrátil",
                "Name[ko]": "Daniel Vrátil",
                "Name[nl]": "Daniel Vrátil",
                "Name[nn]": "Daniel Vrátil",
                "Name[pl]": "Daniel Vrátil",
                "Name[pt]": "Daniel Vrátil",
                "Name[sk]": "Daniel Vrátil",
                "Name[sl]": "Daniel Vrátil",
                "Name[sv]": "Daniel Vrátil",
                "Name[tr]": "Daniel Vrátil",
                "Name[uk]": "Daniel Vrátil",
                "Name[x-test]": "xxDaniel Vrátilxx"
            }
        ],
        "Description": "Runner which searches through your contacts",
        "Description[az]": "Əlaqələriniz üzrə axtarışı başlatmaq üçün vasitə",
        "Description[bg]": "Програма, която извършва търсене във вашите контакти",
        "Description[ca@valencia]": "Executor que busca a través dels vostres contactes",
        "Description[ca]": "Executor que cerca a través dels vostres contactes",
        "Description[de]": "Runner, der Ihre Kontakte durchsucht",
        "Description[es]": "Lanzador que realiza búsquedas en los contactos",
        "Description[fi]": "Haku yhteystiedoista",
        "Description[fr]": "Le lanceur cherchant parmi vos contacts",
        "Description[ia]": "Cursor que cerca per tu contactos",
        "Description[it]": "Esecutore che cerca tra i contatti",
        "Description[ko]": "연락처를 검색하는 실행기",
        "Description[nl]": "Programma dat uw contactpersonen doorzoekt",
        "Description[nn]": "Køyrar som søkjer etter e-postkontaktar",
        "Description[pl]": "Wyszukuje kontakty",
        "Description[pt]": "Um módulo de execução que pesquisa nos seus contactos",
        "Description[sk]": "Program, ktorý prehľadáva vaše kontakty",
        "Description[sl]": "Tekač, ki preišče vaše stike",
        "Description[sv]": "Körprogram som söker igenom kontakter",
        "Description[tr]": "Kişileriniz arasında arama yapan çalıştırıcı",
        "Description[uk]": "Засіб запуску для пошуку у записах ваших контактів",
        "Description[x-test]": "xxRunner which searches through your contactsxx",
        "EnabledByDefault": true,
        "Icon": "view-pim-contacts",
        "Id": "PIM Contacts Search Runner",
        "License": "LGPL",
        "Name": "PIM Contacts Search",
        "Name[az]": "PİM əlaqələri üzrə axtarış",
        "Name[bg]": "Търсене на контакти",
        "Name[ca@valencia]": "Busca de contactes PIM",
        "Name[ca]": "Cerca de contactes PIM",
        "Name[cs]": "Vyhledávání kontaktů PIM",
        "Name[de]": "PIM-Kontaktsuche",
        "Name[es]": "Búsqueda de contactos de PIM",
        "Name[fi]": "Yhteystietohaku",
        "Name[fr]": "Recherche de contact « PIM »",
        "Name[ia]": "Cerca de contactos de PIM",
        "Name[it]": "Ricerca contatti PIM",
        "Name[ko]": "PIM 연락처 검색",
        "Name[nl]": "PIM in contactpersonen zoeken",
        "Name[nn]": "Søk i e-postkontaktar",
        "Name[pl]": "Wyszukiwanie kontaktów ZIO",
        "Name[pt]": "Pesquisa de Contactos PIM",
        "Name[sk]": "Hľadanie kontaktov PIM",
        "Name[sl]": "PIM Contacts Search",
        "Name[sv]": "Kontaktsökning i personlig informationshantering",
        "Name[tr]": "PIM Kişiler Arama",
        "Name[uk]": "Пошук у записах контактів PIM",
        "Name[x-test]": "xxPIM Contacts Searchxx",
        "ServiceTypes": [
            "Plasma/Runner"
        ],
        "Version": "1.0"
    },
    "X-KDE-ConfigModule": "kf@QT_MAJOR_VERSION@/krunner/kcms/kcm_krunner_pimcontacts"
}

==> akonadi-search-22.07.90.tar.xz: akonadi-search-22.07.90/runner/plasma-krunner-pimcontacts.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "dvratil@kde.org",
                "Name": "Daniel Vrátil",
                "Name[az]": "sDaniel Vrátil",
                "Name[bg]": "Daniel Vrátil",
                "Name[ca@valencia]": "Daniel Vrátil",
                "Name[ca]": "Daniel Vrátil",
                "Name[cs]": "Daniel Vrátil",
                "Name[de]": "Daniel Vrátil",
                "Name[en_GB]": "Daniel Vrátil",
                "Name[es]": "Daniel Vrátil",
                "Name[eu]": "Daniel Vrátil",
                "Name[fi]": "Daniel Vrátil",
                "Name[fr]": "Daniel Vrátil",
                "Name[ia]": "Daniel Vrátil",
                "Name[it]": "Daniel Vrátil",
                "Name[ko]": "Daniel Vrátil",
                "Name[nl]": "Daniel Vrátil",
                "Name[nn]": "Daniel Vrátil",
                "Name[pl]": "Daniel Vrátil",
                "Name[pt]": "Daniel Vrátil",
                "Name[pt_BR]": "Daniel Vrátil",
                "Name[sk]": "Daniel Vrátil",
                "Name[sl]": "Daniel Vrátil",
                "Name[sv]": "Daniel Vrátil",
                "Name[tr]": "Daniel Vrátil",
                "Name[uk]": "Daniel Vrátil",
                "Name[x-test]": "xxDaniel Vrátilxx"
            }
        ],
        "Description": "Runner which searches through your contacts",
        "Description[az]": "Əlaqələriniz üzrə axtarışı başlatmaq üçün vasitə",
        "Description[bg]": "Програма, която извършва търсене във вашите контакти",
        "Description[ca@valencia]": "Executor que busca a través dels vostres contactes",
        "Description[ca]": "Executor que cerca a través dels vostres contactes",
        "Description[de]": "Runner, der Ihre Kontakte durchsucht",
        "Description[en_GB]": "Runner which searches through your contacts",
        "Description[es]": "Lanzador que realiza búsquedas en los contactos",
        "Description[eu]": "Zure kontaktuetan barrena bilatzen duen exekutatzailea",
        "Description[fi]": "Haku yhteystiedoista",
        "Description[fr]": "Le lanceur cherchant parmi vos contacts",
        "Description[ia]": "Cursor que cerca per tu contactos",
        "Description[it]": "Esecutore che cerca tra i contatti",
        "Description[ko]": "연락처를 검색하는 실행기",
        "Description[nl]": "Programma dat uw contactpersonen doorzoekt",
        "Description[nn]": "Køyrar som søkjer etter e-postkontaktar",
        "Description[pl]": "Wyszukuje kontakty",
        "Description[pt]": "Um módulo de execução que pesquisa nos seus contactos",
        "Description[pt_BR]": "Módulo de execução que pesquisa nos seus contatos",
        "Description[sk]": "Program, ktorý prehľadáva vaše kontakty",
        "Description[sl]": "Tekač, ki preišče vaše stike",
        "Description[sv]": "Körprogram som söker igenom kontakter",
        "Description[tr]": "Kişileriniz arasında arama yapan çalıştırıcı",
        "Description[uk]": "Засіб запуску для пошуку у записах ваших контактів",
        "Description[x-test]": "xxRunner which searches through your contactsxx",
        "EnabledByDefault": true,
        "Icon": "view-pim-contacts",
        "Id": "PIM Contacts Search Runner",
        "License": "LGPL",
        "Name": "PIM Contacts Search",
        "Name[az]": "PİM əlaqələri üzrə axtarış",
        "Name[bg]": "Търсене на контакти",
        "Name[ca@valencia]": "Busca de contactes PIM",
        "Name[ca]": "Cerca de contactes PIM",
        "Name[cs]": "Vyhledávání kontaktů PIM",
        "Name[de]": "PIM-Kontaktsuche",
        "Name[en_GB]": "PIM Contacts Search",
        "Name[es]": "Búsqueda de contactos de PIM",
        "Name[eu]": "PIM kontaktuen bilaketa",
        "Name[fi]": "Yhteystietohaku",
        "Name[fr]": "Recherche de contact « PIM »",
        "Name[ia]": "Cerca de contactos de PIM",
        "Name[it]": "Ricerca contatti PIM",
        "Name[ko]": "PIM 연락처 검색",
        "Name[nl]": "PIM in contactpersonen zoeken",
        "Name[nn]": "Søk i e-postkontaktar",
        "Name[pl]": "Wyszukiwanie kontaktów ZIO",
        "Name[pt]": "Pesquisa de Contactos PIM",
        "Name[pt_BR]": "Pesquisa de contatos PIM",
        "Name[sk]": "Hľadanie kontaktov PIM",
        "Name[sl]": "PIM Contacts Search",
        "Name[sv]": "Kontaktsökning i personlig informationshantering",
        "Name[tr]": "PIM Kişiler Arama",
        "Name[uk]": "Пошук у записах контактів PIM",
        "Name[x-test]": "xxPIM Contacts Searchxx",
        "ServiceTypes": [
            "Plasma/Runner"
        ],
        "Version": "1.0"
    },
    "X-KDE-ConfigModule": "kf@QT_MAJOR_VERSION@/krunner/kcms/kcm_krunner_pimcontacts"
}
